@@ -9,8 +9,8 @@ from send2trash import send2trash as s2t
 
 # import the two versions as well as the "automatic" version
 if sys.platform == "win32":
-    from send2trash.plat_win_modern import send2trash as s2t_modern
-    from send2trash.plat_win_legacy import send2trash as s2t_legacy
+    from send2trash.win.modern import send2trash as s2t_modern
+    from send2trash.win.legacy import send2trash as s2t_legacy
 else:
     pytest.skip("Skipping windows-only tests", allow_module_level=True)
 
@@ -144,7 +144,10 @@ def longdir(tmp_path):
     dirname = "\\\\?\\" + str(tmp_path)
     name = "A" * 100
     yield op.join(dirname, name, name, name)
-    shutil.rmtree(dirname, ignore_errors=True)
+    try:
+        shutil.rmtree(dirname, ignore_errors=True)
+    except TypeError:
+        pass
 
 
 @pytest.fixture
@@ -201,3 +204,17 @@ def test_trash_long_multifile_legacy(longfiles):
 #     )
 #     def test_trash_long_folder_legacy(self):
 #         self._trash_folder(s2t_legacy)
+
+
+def test_trash_nothing_legacy():
+    try:
+        s2t_legacy([])
+    except Exception as ex:
+        assert False, "Exception thrown when trashing nothing: {}".format(ex)
+
+
+def test_trash_nothing_modern():
+    try:
+        s2t_modern([])
+    except Exception as ex:
+        assert False, "Exception thrown when trashing nothing: {}".format(ex)
